summaryrefslogtreecommitdiff
path: root/internal/executor/executor_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/executor/executor_test.go')
-rw-r--r--internal/executor/executor_test.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/internal/executor/executor_test.go b/internal/executor/executor_test.go
index c68d37b..a8fd9da 100644
--- a/internal/executor/executor_test.go
+++ b/internal/executor/executor_test.go
@@ -1832,12 +1832,12 @@ func TestPool_StoryDeploy_MergesStoryBranch(t *testing.T) {
runGit(t, localDir, "config", "user.email", "test@test.com")
runGit(t, localDir, "config", "user.name", "Test")
- // Initial commit on master.
- runGit(t, localDir, "checkout", "-b", "master")
+ // Initial commit on main.
+ runGit(t, localDir, "checkout", "-b", "main")
os.WriteFile(filepath.Join(localDir, "README.md"), []byte("initial"), 0644)
runGit(t, localDir, "add", ".")
runGit(t, localDir, "commit", "-m", "initial")
- runGit(t, localDir, "push", "-u", "origin", "master")
+ runGit(t, localDir, "push", "-u", "origin", "main")
// Story branch with a feature commit.
runGit(t, localDir, "checkout", "-b", "story/test-feature")
@@ -1845,7 +1845,7 @@ func TestPool_StoryDeploy_MergesStoryBranch(t *testing.T) {
runGit(t, localDir, "add", ".")
runGit(t, localDir, "commit", "-m", "feature work")
runGit(t, localDir, "push", "origin", "story/test-feature")
- runGit(t, localDir, "checkout", "master")
+ runGit(t, localDir, "checkout", "main")
store := testStore(t)
logger := slog.New(slog.NewTextHandler(os.Stderr, &slog.HandlerOptions{Level: slog.LevelError}))
@@ -1872,9 +1872,9 @@ func TestPool_StoryDeploy_MergesStoryBranch(t *testing.T) {
pool.triggerStoryDeploy(context.Background(), story.ID)
// feature.go should now be on master in the working copy.
if _, err := os.Stat(filepath.Join(localDir, "feature.go")); os.IsNotExist(err) {
- t.Error("story branch was not merged to master: feature.go missing")
+ t.Error("story branch was not merged to main: feature.go missing")
}
got, _ := store.GetStory(story.ID)
if got.Status != task.StoryDeployed {
@@ -1872,9 +1872,9 @@ func TestPool_StoryDeploy_MergesStoryBranch(t *testing.T) {
pool.triggerStoryDeploy(context.Background(), story.ID)
- // feature.go should now be on master in the working copy.
+ // feature.go should now be on main in the working copy.
if _, err := os.Stat(filepath.Join(localDir, "feature.go")); os.IsNotExist(err) {